@@ -13,7 +13,9 @@ from pytensor.tensor.exceptions import NotScalarConstantError
 from pytensor.tensor.type import integer_dtypes
 from pytensor.tensor.utils import get_static_shape_from_size_variables
 from pytensor.xtensor.basic import XOp
-from pytensor.xtensor.type import as_xtensor, xtensor
+from pytensor.xtensor.math import cast, second
+from pytensor.xtensor.type import XTensorVariable, as_xtensor, xtensor
+from pytensor.xtensor.vectorization import combine_dims_and_shape
 
 
 class Stack(XOp):
@@ -189,7 +191,7 @@ class Transpose(XOp):
 
 def transpose(
     x,
-    *dims: str | EllipsisType,
+    *dim: str | EllipsisType,
     missing_dims: Literal["raise", "warn", "ignore"] = "raise",
 ):
     """Transpose dimensions of the tensor.
@@ -198,7 +200,7 @@ def transpose(
     ----------
     x : XTensorVariable
         Input tensor to transpose.
-    *dims : str
+    *dim : str
         Dimensions to transpose to. Can include ellipsis (...) to represent
         remaining dimensions in their original order.
     missing_dims : {"raise", "warn", "ignore"}, optional
@@ -220,7 +222,7 @@ def transpose(
     # Validate dimensions
     x = as_xtensor(x)
     x_dims = x.type.dims
-    invalid_dims = set(dims) - {..., *x_dims}
+    invalid_dims = set(dim) - {..., *x_dims}
     if invalid_dims:
         if missing_dims != "ignore":
             msg = f"Dimensions {invalid_dims} do not exist. Expected one or more of: {x_dims}"
@@ -229,21 +231,27 @@ def transpose(
             else:
                 warnings.warn(msg)
         # Handle missing dimensions if not raising
-        dims = tuple(d for d in dims if d in x_dims or d is ...)
+        dim = tuple(d for d in dim if d in x_dims or d is ...)
 
-    if dims == () or dims == (...,):
-        dims = tuple(reversed(x_dims))
-    elif ... in dims:
-        if dims.count(...) > 1:
+    if dim == ():
+        dim = tuple(reversed(x_dims))
+    elif dim == (...,):
+        dim = x_dims
+    elif ... in dim:
+        if dim.count(...) > 1:
             raise ValueError("Ellipsis (...) can only appear once in the dimensions")
         # Handle ellipsis expansion
-        ellipsis_idx = dims.index(...)
-        pre = dims[:ellipsis_idx]
-        post = dims[ellipsis_idx + 1 :]
+        ellipsis_idx = dim.index(...)
+        pre = dim[:ellipsis_idx]
+        post = dim[ellipsis_idx + 1 :]
         middle = [d for d in x_dims if d not in pre + post]
-        dims = (*pre, *middle, *post)
+        dim = (*pre, *middle, *post)
 
-    return Transpose(typing.cast(tuple[str], dims))(x)
+    if dim == x_dims:
+        # No-op transpose
+        return x
+
+    return Transpose(dims=typing.cast(tuple[str], dim))(x)
 
 
 class Concat(XOp):
@@ -295,6 +303,35 @@ class Concat(XOp):
 
 
 def concat(xtensors, dim: str):
+    """Concatenate a sequence of XTensorVariables along a specified dimension.
+
+    Parameters
+    ----------
+    xtensors : Sequence of XTensorVariable
+        The tensors to concatenate.
+    dim : str
+        The dimension along which to concatenate the tensors.
+
+    Returns
+    -------
+    XTensorVariable
+
+
+    Example
+    -------
+
+    .. testcode::
+
+        from pytensor.xtensor import as_xtensor, xtensor, concat
+
+        x = xtensor("x", shape=(2, 3), dims=("a", "b"))
+        zero = as_xtensor([0], dims=("a"))
+
+        out = concat([zero, x, zero], dim="a")
+        assert out.type.dims == ("a", "b")
+        assert out.type.shape == (4, 3)
+
+    """
     return Concat(dim=dim)(*xtensors)
 
 
@@ -498,3 +535,160 @@ def expand_dims(x, dim=None, create_index_for_new_dim=None, axis=None, **dim_kwa
         x = Transpose(dims=tuple(target_dims))(x)
 
     return x
+
+
+class Broadcast(XOp):
+    """Broadcast multiple XTensorVariables against each other."""
+
+    __props__ = ("exclude",)
+
+    def __init__(self, exclude: Sequence[str] = ()):
+        self.exclude = tuple(exclude)
+
+    def make_node(self, *inputs):
+        inputs = [as_xtensor(x) for x in inputs]
+
+        exclude = self.exclude
+        dims_and_shape = combine_dims_and_shape(inputs, exclude=exclude)
+
+        broadcast_dims = tuple(dims_and_shape.keys())
+        broadcast_shape = tuple(dims_and_shape.values())
+        dtype = upcast(*[x.type.dtype for x in inputs])
+
+        outputs = []
+        for x in inputs:
+            x_dims = x.type.dims
+            x_shape = x.type.shape
+            # The output has excluded dimensions in the order they appear in the op argument
+            excluded_dims = tuple(d for d in exclude if d in x_dims)
+            excluded_shape = tuple(x_shape[x_dims.index(d)] for d in excluded_dims)
+
+            output = xtensor(
+                dtype=dtype,
+                shape=broadcast_shape + excluded_shape,
+                dims=broadcast_dims + excluded_dims,
+            )
+            outputs.append(output)
+
+        return Apply(self, inputs, outputs)
+
+
+def broadcast(
+    *args, exclude: str | Sequence[str] | None = None
+) -> tuple[XTensorVariable, ...]:
+    """Broadcast any number of XTensorVariables against each other.
+
+    Parameters
+    ----------
+    *args : XTensorVariable
+        The tensors to broadcast against each other.
+    exclude : str or Sequence[str] or None, optional
+    """
+    if not args:
+        return ()
+
+    if exclude is None:
+        exclude = ()
+    elif isinstance(exclude, str):
+        exclude = (exclude,)
+    elif not isinstance(exclude, Sequence):
+        raise TypeError(f"exclude must be None, str, or Sequence, got {type(exclude)}")
+    # xarray broadcast always returns a tuple, even if there's only one tensor
+    return tuple(Broadcast(exclude=exclude)(*args, return_list=True))  # type: ignore
+
+
+def full_like(x, fill_value, dtype=None):
+    """Create a new XTensorVariable with the same shape and dimensions, filled with a specified value.
+
+    Parameters
+    ----------
+    x : XTensorVariable
+        The tensor to fill.
+    fill_value : scalar or XTensorVariable
+        The value to fill the new tensor with.
+    dtype : str or np.dtype, optional
+        The data type of the new tensor. If None, uses the dtype of the input tensor.
+
+    Returns
+    -------
+    XTensorVariable
+        A new tensor with the same shape and dimensions as self, filled with fill_value.
+
+    Examples
+    --------
+    >>> from pytensor.xtensor import xtensor, full_like
+    >>> x = xtensor(dtype="float64", dims=("a", "b"), shape=(2, 3))
+    >>> y = full_like(x, 5.0)
+    >>> assert y.dims == ("a", "b")
+    >>> assert y.type.shape == (2, 3)
+    """
+    x = as_xtensor(x)
+    fill_value = as_xtensor(fill_value)
+
+    # Check that fill_value is a scalar (ndim=0)
+    if fill_value.type.ndim != 0:
+        raise ValueError(
+            f"fill_value must be a scalar, got ndim={fill_value.type.ndim}"
+        )
+
+    # Handle dtype conversion
+    if dtype is not None:
+        # If dtype is specified, cast the fill_value to that dtype
+        fill_value = cast(fill_value, dtype)
+    else:
+        # If dtype is None, cast the fill_value to the input tensor's dtype
+        # This matches xarray's behavior where it preserves the original dtype
+        fill_value = cast(fill_value, x.type.dtype)
+
+    # Use the xtensor second function
+    return second(x, fill_value)
+
+
+def ones_like(x, dtype=None):
+    """Create a new XTensorVariable with the same shape and dimensions, filled with ones.
+
+    Parameters
+    ----------
+    x : XTensorVariable
+        The tensor to fill.
+    dtype : str or np.dtype, optional
+        The data type of the new tensor. If None, uses the dtype of the input tensor.
+
+    Returns:
+    XTensorVariable
+        A new tensor with the same shape and dimensions as self, filled with ones.
+
+    Examples
+    --------
+    >>> from pytensor.xtensor import xtensor, full_like
+    >>> x = xtensor(dtype="float64", dims=("a", "b"), shape=(2, 3))
+    >>> y = ones_like(x)
+    >>> assert y.dims == ("a", "b")
+    >>> assert y.type.shape == (2, 3)
+    """
+    return full_like(x, 1.0, dtype=dtype)
+
+
+def zeros_like(x, dtype=None):
+    """Create a new XTensorVariable with the same shape and dimensions, filled with zeros.
+
+    Parameters
+    ----------
+    x : XTensorVariable
+        The tensor to fill.
+    dtype : str or np.dtype, optional
+        The data type of the new tensor. If None, uses the dtype of the input tensor.
+
+    Returns:
+    XTensorVariable
+        A new tensor with the same shape and dimensions as self, filled with zeros.
+
+    Examples
+    --------
+    >>> from pytensor.xtensor import xtensor, full_like
+    >>> x = xtensor(dtype="float64", dims=("a", "b"), shape=(2, 3))
+    >>> y = zeros_like(x)
+    >>> assert y.dims == ("a", "b")
+    >>> assert y.type.shape == (2, 3)
+    """
+    return full_like(x, 0.0, dtype=dtype)
